DeviceInfoAppPlatform class abstract

The interface that platform-specific implementations of this plugin must implement.

Platform implementations should extend this class rather than implement it as DeviceInfoAppPlatform, so new methods added here don't break existing implementations.

Inheritance
  • Object
  • PlatformInterface
  • DeviceInfoAppPlatform
Implementers

Constructors

DeviceInfoAppPlatform()
Constructs a DeviceInfoAppPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInfo() Future<DeviceInfo>
Retrieves device and app information from the native platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DeviceInfoAppPlatform
The default instance of DeviceInfoAppPlatform to use.
getter/setter pair