getDeviceInfo method
Retrieves device and app information from the native platform.
Implementation
Future<DeviceInfo> getDeviceInfo() {
throw UnimplementedError('getDeviceInfo() has not been implemented');
}
Retrieves device and app information from the native platform.
Future<DeviceInfo> getDeviceInfo() {
throw UnimplementedError('getDeviceInfo() has not been implemented');
}