LocaleApp class

The device's language and country locale, split into components.

Constructors

LocaleApp({String languageCode = '', String countryCode = ''})
Creates a LocaleApp, defaulting to empty codes.
const
LocaleApp.fromJson(Map json)
Builds a LocaleApp from the map returned by the native platform.

Properties

countryCode String
ISO 3166-1 alpha-2 country code (e.g. "US").
final
hashCode int
The hash code for this object.
no setterinherited
languageCode String
ISO 639 language code (e.g. "en").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited