Utsname class

POSIX uname() info. Populated on both Android and iOS since both run on top of a kernel that exposes this via the uname syscall.

Constructors

Utsname({String sysname = '', String nodename = '', String release = '', String version = '', String machine = ''})
Creates a Utsname, defaulting to empty values.
const
Utsname.fromJson(Map json)
Builds a Utsname from the map returned by the native platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
machine String
The hardware identifier.
final
nodename String
The network node hostname.
final
release String
The operating system release.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sysname String
The operating system name.
final
version String
The operating system version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Utsname to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited