DeviceInfo class
Constructors
-
DeviceInfo({String versionNumber = '', String buildNumber = '', String displayName = '', String bundleName = '', String uuid = '', String locales = '', String timeZone = '', String alphaCode = '', LocaleApp localeApp = const LocaleApp(), bool isLowRamDevice = false, int physicalRamSize = 0, int availableRamSize = 0, int totalRam = 0, String board = '', String bootloader = '', String device = '', String display = '', String fingerprint = '', String hardware = '', String host = '', String buildId = '', String product = '', List<
String> supported32BitAbis = const [], List<String> supported64BitAbis = const [], List<String> supportedAbis = const [], String tags = '', String type = '', List<String> systemFeatures = const [], String deviceName = '', String modelName = '', String localizedModel = '', bool isiOSAppOnMac = false, String brand = '', String manufacturer = '', String model = '', String systemName = '', String systemVersion = '', bool isPhysicalDevice = true, int freeDiskSize = 0, int totalDiskSize = 0, Utsname utsname = const Utsname()}) - DeviceInfo.fromJson(Map json)
Properties
- alphaCode → String
-
final
- areaCode → String
-
International dial code derived from alphaCode (e.g. "VN" -> "84").
Computed on read so it can never diverge from alphaCode.
no setter
- availableRamSize → int
-
final
- board → String
-
final
- bootloader → String
-
final
- brand → String
-
final
- buildId → String
-
final
- buildNumber → String
-
final
- bundleName → String
-
final
- device → String
-
final
- deviceName → String
-
final
- display → String
-
final
- displayName → String
-
final
- fingerprint → String
-
final
- freeDiskSize → int
-
final
- hardware → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- isiOSAppOnMac → bool
-
final
- isLowRamDevice → bool
-
final
- isPhysicalDevice → bool
-
final
- localeApp → LocaleApp
-
final
- locales → String
-
final
- localizedModel → String
-
final
- manufacturer → String
-
final
- model → String
-
Device model. Not equivalent across platforms: on Android this is
the specific hardware model (
Build.MODEL, e.g. "SM-G991B"); on iOS this is only the generic device type (UIDevice.current.model, e.g. "iPhone" or "iPad"). For the specific iOS hardware identifier (e.g. "iPhone14,2"), use modelName instead.final - modelName → String
-
final
- physicalRamSize → int
-
final
- product → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supported32BitAbis
→ List<
String> -
final
-
supported64BitAbis
→ List<
String> -
final
-
supportedAbis
→ List<
String> -
final
-
systemFeatures
→ List<
String> -
final
- systemName → String
-
final
- systemVersion → String
-
final
-
final
- timeZone → String
-
final
- totalDiskSize → int
-
final
- totalRam → int
-
final
- type → String
-
final
- utsname → Utsname
-
final
- uuid → String
-
final
- versionNumber → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited