Utsname class

POSIX uname() info. Populated on both Android and iOS since both run on top of a kernel that exposes this via the uname syscall.

Constructors

Utsname({String sysname = '', String nodename = '', String release = '', String version = '', String machine = ''})
const
Utsname.fromJson(Map json)

Properties

hashCode int
The hash code for this object.
no setterinherited
machine String
final
nodename String
final
release String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sysname String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited